package file

import (
	"encoding/json"
	"net/http"
	"os"

	"ppt_server/app/model"
	pHttp "ppt_server/library/http"

	"github.com/gogf/gf/errors/gerror"
	"github.com/gogf/gf/frame/g"
	"github.com/gogf/gf/text/gregex"
)

type notify struct {
	name     string
	password string
	url      string
	client   *pHttp.SessionHttpClient
}

var n = notify{
	url:      g.Cfg().GetString("notify.url"),
	name:     os.Getenv("live_name"),
	password: os.Getenv("live_pwd"),
	client:   pHttp.NewSessionHttpClient(),
}

//回调验权
func (n notify) verify(url string, data g.Map) error {
	res, err := n.client.Post(url, data)
	if err != nil {
		return err
	}
	g.Log().Async().Infof("url: %s, res: %s", url, string(res))

	var notifyResponse model.NotifyResponse
	if err = json.Unmarshal(res, &notifyResponse); err != nil {
		return err
	}
	if notifyResponse.Code != http.StatusOK {
		return gerror.New(notifyResponse.Msg)
	}
	return nil
}

// 登录
func (n notify) auth(data g.Map) error {

	if err := n.verify(n.url+"/web/login", g.Map{
		"name":     n.name,
		"password": n.password,
	}); err != nil {
		return err
	}
	// 获取Token
	bufferBytes, err := n.client.Get(n.url + "/web/admin")
	if err != nil {
		return err
	}

	buf, _ := gregex.Match(reTokenPattern, bufferBytes)
	data["_token"] = string(buf[1])

	return nil
}

// 发送通知
func (n notify) notice(path string, data g.Map) error {
	if err := n.auth(data); err != nil {
		return err
	}
	return n.verify(n.url+path, data)
}
